==> haskell-uuid-1.3.16-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uuid
version:              1.3.16
visibility:           public
id:                   uuid-1.3.16-KPqM7fkGU7HIYn98FEGylF
key:                  uuid-1.3.16-KPqM7fkGU7HIYn98FEGylF
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  2d2b12d21fe011a73b2f55596a51986c
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uuid
hs-libraries:         HSuuid-1.3.16-KPqM7fkGU7HIYn98FEGylF
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cryptohash-md5-0.11.101.0-CZSAC1Ae9VC9A8vP1fCKiS
    cryptohash-sha1-0.11.101.0-AZqs0K3dvPG5kQ7BamXUfA
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-info-0.2.1-DF9aJuNW45HC0966sT94Vy
    random-1.2.1.3-2Hw42CquWtj55joOjOmzRr text-2.0.2 time-1.12.2
    uuid-types-1.0.6-1cjjiQgFLzL6lLsdFHJBaX

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.16-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uuid
version:              1.3.16
visibility:           public
id:                   uuid-1.3.16-8DXJEeeES9kGcCaO3OL4N3
key:                  uuid-1.3.16-8DXJEeeES9kGcCaO3OL4N3
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  ffefea7828dbc54af42c5213804d8780
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uuid-1.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uuid
hs-libraries:         HSuuid-1.3.16-8DXJEeeES9kGcCaO3OL4N3
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cryptohash-md5-0.11.101.0-GA7lMhOif5dI0BE1U3dLTX
    cryptohash-sha1-0.11.101.0-KG6IUQP4rbXDet4xbFPhLZ
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    network-info-0.2.1-DF9aJuNW45HC0966sT94Vy
    random-1.2.1.3-LY8g0he9kPzH0WCF9vQLty text-2.0.2 time-1.12.2
    uuid-types-1.0.6-HYU7viivqgX5aZerV0Z0Cp

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
